@@ -13,7 +13,7 @@ class KeycloakUserManager(UserManager):
         """
         Creates a local user if the user exists on keycloak
         """
-        token = self.keycloak.get_token_from_credentials(username, password)
+        token = self.keycloak.get_token_from_credentials(username, password).get("access_token")
         if token is None:
             raise ValueError("Wrong credentials")
         user = self.create_from_token(token, password)
@@ -23,7 +23,7 @@ class KeycloakUserManager(UserManager):
         """
         Creates a local super user if the user exists on keycloak and is superuser
         """
-        token = self.keycloak.get_token_from_credentials(username, password)
+        token = self.keycloak.get_token_from_credentials(username, password).get("access_token")
         if token is None:
             raise ValueError("Wrong credentials")
         if not self.keycloak.has_superuser_perm(token):
@@ -59,3 +59,38 @@ class KeycloakUserManager(UserManager):
         )
         user.save(using=self._db)
         return user
+
+    def get_by_keycloak_id(self, keycloak_id):
+        return self.get(id=keycloak_id)
+
+
+class KeycloakUserManagerAutoId(KeycloakUserManager):
+    def create_from_token(self, token, password=None, **kwargs):
+        """
+        Create a new user from a valid token
+        """
+        if not self.keycloak.is_token_active(token):
+            raise ValueError("Invalid token")
+
+        user_info = self.keycloak.introspect(token)
+
+        # set admin permissions if user is admin
+        is_staff = False
+        is_superuser = False
+        if self.keycloak.has_superuser_perm(token):
+            is_staff = True
+            is_superuser = True
+
+        user = self.model(
+            keycloak_id=user_info.get("sub"),
+            username=user_info.get("username"),
+            is_staff=is_staff,
+            is_superuser=is_superuser,
+            date_joined=timezone.now(),
+            **kwargs
+        )
+        user.save(using=self._db)
+        return user
+
+    def get_by_keycloak_id(self, keycloak_id):
+        return self.get(keycloak_id=keycloak_id)
